Documentation
¶
Index ¶
Constants ¶
const ( // Base2 alphabet Base2 = "01" // Base16 alphabet Base16 = "0123456789abcdef" // Base32 alphabet Base32 = "0123456789ABCDEFGHJKMNPQRSTVWXYZ" // Base62 alphabet Base62 = "0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Encoding ¶
type Encoding struct {
// contains filtered or unexported fields
}
Encoding is a custom base encoding defined by an alphabet
func NewEncoding ¶
NewEncoding returns a custom base encoder defined by the alphabet string
Click to show internal directories.
Click to hide internal directories.